/**
 * Value object representing a commit message body
 */
export declare class CommitBody {
    private readonly BREAKING_CHANGE;
    private readonly CONTENT;
    constructor(content?: string, breakingChange?: string);
    /**
     * Check if two bodies are equal
     * @param {CommitBody} other - The other commit body to compare with
     * @returns {boolean} True if the bodies are equal
     */
    equals(other: CommitBody): boolean;
    /**
     * Get the breaking change description
     * @returns {string | undefined} The breaking change description or undefined
     */
    getBreakingChange(): string | undefined;
    /**
     * Get the body content
     * @returns {string | undefined} The body content or undefined
     */
    getContent(): string | undefined;
    /**
     * Check if there is a breaking change
     * @returns {boolean} True if there is a breaking change
     */
    hasBreakingChange(): boolean;
    /**
     * Check if the body is empty
     * @returns {boolean} True if the body is empty
     */
    isEmpty(): boolean;
    /**
     * Format the body as a string
     * @returns {string} The formatted body text
     */
    toString(): string;
}
